package de.groygroy.wahl2009;

import java.util.Arrays;


/**
 * Einfaches POJO, enthält Wahlergebniss und Metadaten für ein Stadtteil.
 *
 * <p>Wird aus CSV Datei mit folgenden Spalten gefüttert:
 *
 * <pre>
 * #Wahlkreis;"Stadtteil";"Position";"Wahlberechtigte ohne Wahlscheinvermerk";"Wahlberechtigte mit Wahlscheinvermerk";"Wahlberechtigte insgesamt";"Wähler insgesamt";"darunter mit Wahlschein";"ungültige Stimmen";"gültige Stimmen";"SPD Stimmen";"SPD Anteil";"CDU Stimmen";"CDU Anteil";"GRÜNE/GAL";"GRÜNE/GAL";"FDP";"FDP";"DIE LINKE";"DIE LINKE";"Sonstige Stimmen";;"NPD";"MLPD";"ödp Hamburg";"BüSo";"FÜR VOLKSENTSCHEIDE";"Mensch macht Politik"
 * </pre>
 *
 * @author  cz
 */
public class Stadtteil implements Comparable {
    private int gültigeStimmen;
    private String position;
    private String stadtteil;
    private int stimmenCDU;
    private int stimmenDIE_LINKE;
    private int stimmenFDP;
    private int stimmenGRÜNE_GAL;
    private int stimmenSonstige;
    private int stimmenSPD;
    private int ungültigeStimmen;
    private int wahlberechtigteInsgesamt;
    private String wahlkreis;

    Stadtteil( String[] csvLine ) {

        if ( ( csvLine == null ) || ( 28 != csvLine.length ) ) {
            throw new IllegalArgumentException( "erwarte csv line mit 28 spalten, erhielt " +
                ( ( csvLine != null ) ? Arrays.toString( csvLine ) : "null" ) );
        }

        this.wahlkreis = csvLine[ 0 ].replaceAll( "\"", "" );
        this.stadtteil = csvLine[ 1 ].replaceAll( "\"", "" );
        this.position = csvLine[ 2 ].replaceAll( "\"", "" );
        this.wahlberechtigteInsgesamt = Integer.parseInt( csvLine[ 5 ] );
        this.ungültigeStimmen = Integer.parseInt( csvLine[ 8 ] );
        this.gültigeStimmen = Integer.parseInt( csvLine[ 9 ] );
        this.stimmenSPD = Integer.parseInt( csvLine[ 10 ] );
        this.stimmenCDU = Integer.parseInt( csvLine[ 12 ] );
        this.stimmenGRÜNE_GAL = Integer.parseInt( csvLine[ 14 ] );
        this.stimmenFDP = Integer.parseInt( csvLine[ 16 ] );
        this.stimmenDIE_LINKE = Integer.parseInt( csvLine[ 18 ] );
        this.stimmenSonstige = Integer.parseInt( csvLine[ 20 ] );
    }

    public int compareTo( Object o ) {

        if ( o instanceof Stadtteil ) {
            return ( ( Stadtteil ) o ).getStadtteil().compareTo( getStadtteil() );
        }

        return 0;
    }

    public int getGültigeStimmen() {
        return gültigeStimmen;
    }

    public String getPosition() {
        return position;
    }

    public double getProzentCDU() {
        return ( 100.0 * getStimmenCDU() ) / getGültigeStimmen();
    }

    public double getProzentDIE_LINKE() {
        return ( 100.0 * getStimmenDIE_LINKE() ) / getGültigeStimmen();
    }

    public double getProzentFDP() {
        return ( 100.0 * getStimmenFDP() ) / getGültigeStimmen();
    }

    public double getProzentGRÜNE_GAL() {
        return ( 100.0 * getStimmenGRÜNE_GAL() ) / getGültigeStimmen();
    }

    public double getProzentSonstige() {
        return ( 100.0 * getStimmenSonstige() ) / getGültigeStimmen();
    }

    public double getProzentSPD() {
        return ( 100.0 * getStimmenSPD() ) / getGültigeStimmen();
    }

    public String getStadtteil() {
        return stadtteil;
    }

    public int getStimmen() {
        return getUngültigeStimmen() + getGültigeStimmen();
    }

    public int getStimmenCDU() {
        return stimmenCDU;
    }

    public int getStimmenDIE_LINKE() {
        return stimmenDIE_LINKE;
    }

    public int getStimmenFDP() {
        return stimmenFDP;
    }

    public int getStimmenGRÜNE_GAL() {
        return stimmenGRÜNE_GAL;
    }

    public int getStimmenSonstige() {
        return stimmenSonstige;
    }

    public int getStimmenSPD() {
        return stimmenSPD;
    }

    public int getUngültigeStimmen() {
        return ungültigeStimmen;
    }

    public int getWahlberechtigteInsgesamt() {
        return wahlberechtigteInsgesamt;
    }

    public String getWahlkreis() {
        return wahlkreis;
    }

}
